( cd usr/lib ; rm -rf libloginhelper.so.0 )
( cd usr/lib ; ln -sf libloginhelper.so.0.0.0 libloginhelper.so.0 )
( cd usr/lib ; rm -rf libspi.so )
( cd usr/lib ; ln -sf libspi.so.0.10.11 libspi.so )
( cd usr/lib ; rm -rf libcspi.so.0 )
( cd usr/lib ; ln -sf libcspi.so.0.10.11 libcspi.so.0 )
( cd usr/lib ; rm -rf libloginhelper.so )
( cd usr/lib ; ln -sf libloginhelper.so.0.0.0 libloginhelper.so )
( cd usr/lib ; rm -rf libcspi.so )
( cd usr/lib ; ln -sf libcspi.so.0.10.11 libcspi.so )
( cd usr/lib ; rm -rf libspi.so.0 )
( cd usr/lib ; ln -sf libspi.so.0.10.11 libspi.so.0 )
#%% begin initialize at_spi-1.26.0-i586-P1
if [ -x /usr/bin/gconftool-2 ]; then
    ( cd /etc/gconf/schemas ; GCONF_CONFIG_SOURCE=xml:merged:/etc/gconf/gconf.xml.defaults /usr/bin/gconftool-2 --makefile-install-rule at-spi.schemas )
fi
#%% end
